Module hoardbase::database [−][src]
Structs
The core struct that represents a database.
This struct can config a database. This struct uses the builder pattern.
If a user wants to execute multiple statements in a Transaction, she needs to obtain a Transaction object first. This object provides a similar interface to that of a Database object. A user should be able to perform the same set operations on a Transaction object as a Database object.